package insurance;


import com.metamaxim.modelscope.callbacks.Behaviour;
import com.metamaxim.modelscope.callbacks.Instance;

import insurance.helper.DateUtils;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;


public class Claim extends Behaviour {

    public int getTotalAmount() {
        int number = this.getInteger("Number");
        return number * this.getCurrency("Price");
    }

    /**
     * computes total used number in this year.
     * @return
     */
    public int getTotalNumber() {
        Date date = this.getDate("Service Date");
        Calendar cal = new GregorianCalendar();
        cal.setTime(date);

        int year = cal.get(Calendar.YEAR);

        Calendar cal2 = new GregorianCalendar();
        cal2.clear();
        cal2.set(year, 0, 1, 0, 0, 0);
        Date startDate = cal2.getTime();
        cal2.set(Calendar.MONTH, 11);
        cal2.set(Calendar.DAY_OF_MONTH, 31);
        Date endDate = cal2.getTime();

        Instance policy = this.getInstance("Policy");
        Instance procedure = this.getInstance("CareProcedure");

        Instance[] claims = policy.selectByRef("Claim", "Policy");
        int totalNumber = 0;

        for (Instance claim : claims) {
            String status = claim.getState("Claim");
            if ("Processed".equalsIgnoreCase(status)) {
                if (claim.getInstance("CareProcedure").equals(procedure)) {
                    date = claim.getDate("Service Date");
                    if (date.compareTo(startDate) >= 0 &&
                        date.compareTo(endDate) <= 0) {
                        totalNumber += claim.getInteger("Number");
                    }
                }
            }
        }

        return totalNumber;
    }

    public int getMemberAge() {
        Date birthDate =
            this.getInstance("Policy").getInstance("Person").getDate("Date of Birth");
        Date date = this.getDate("Service Date");
            
        return DateUtils.getAgeAtDate(birthDate, date);
    }
}
