package insurance;


import com.metamaxim.modelscope.callbacks.Behaviour;
import com.metamaxim.modelscope.callbacks.Instance;

import insurance.helper.ProcessingContext;


/**
 * Benefits are granted up to a maximum number per coverage.
 */
public class MaximumNumberCondition extends Behaviour {

    public int getMaximumNumber() {
        Instance policyCoverage = this.getInstance("Coverage");
        int maximum = policyCoverage.getInteger("Maximum Number");
        return maximum;
    }

    public int getUsedNumber() {
        Instance[] claims =
            this.selectByRef("Claim", "PolicyCoverage");
        int totalNumber = 0;

        for (Instance claim : claims) {
            String status = claim.getState("Claim");
            if ("Processed".equalsIgnoreCase(status)) {
                totalNumber += claim.getInteger("Number");
            }
        }

        return totalNumber;
    }

    public String getState() {
        Instance currentClaim = ProcessingContext.getCurrentClaim();
        if (currentClaim == null) {
            return "Exceeded";
        }
        int total = this.getInteger("Used Number");
        total += currentClaim.getInteger("Number");
        //get Maximum from related coverage
        Instance policyCoverage = this.getInstance("Coverage");
        int maximum = policyCoverage.getInteger("Maximum Number");

        if (maximum != 0) {
            if (total > maximum) {
                return "Exceeded";
            }
        }
        return "Not exceeded";
    }
}
