package insurance;


import insurance.helper.ProcessingContext;

import com.metamaxim.modelscope.callbacks.Event;
import com.metamaxim.modelscope.callbacks.Instance;

import java.util.ArrayList;
import java.util.List;

/**
 * Processes the Submit Claim event. Searches the one and only policy coverage that can process the claim.
 * If zero or more than 1 is found, this is a setup error.
 */
public class SubmitClaim extends Event {

    public void handleEvent() {
        //Get product and claim from event
        Instance claim=this.getInstance("Claim");
        ProcessingContext.setCurrentClaim(claim);
        Instance policy = claim.getInstance("Policy");
        
        //find all coverages that can process the event: should be exactly one.
        Instance[] coverages = policy.selectInContext("PolicyCoverage", "Process Claim");
        
        List<Instance> policyCoverageList = new ArrayList<Instance>();
        for (Instance coverage: coverages) {
            Instance coveragePolicy = coverage.getInstance("Policy");
            if (coveragePolicy.equals(policy)) {
                policyCoverageList.add(coverage);
            }
        }
        if (policyCoverageList.size() != 1) {
            log (policyCoverageList);
            Event event = this.createEvent("Reject Claim");
            event.setInstance("Claim", claim);
            event.setString("Processing Info", "Rejected: "+  coverages.length + " coverages found");
            event.log();
            event.submitToModel();
        }
        else {
            //Create processClaim event
            Event event = this.createEvent("Process Claim");
            event.setInstance("PolicyCoverage", policyCoverageList.get(0));
            event.setInstance("Claim", claim);
            event.log();
            event.submitToCallback();
        }
    }
    
    private void log (List<Instance> coverages) {
        for (Instance coverage: coverages) {
            System.out.println("ObjectType=" + coverage.getObjectType());
        }
    }
}
